@@ -37,7 +37,7 @@ class Spliter:
             self.long_filter = re.compile('([.?!。？！，,])')
 
 
-    def cut_to_sentences(self, text):
+    def cut_to_sentences(self,text):
 
         if self.remove_blank_on and self.flag == 'zh':
             text = re.sub(r'\s+', '', text)  # 先不考虑中英文混合情况,去掉空格
@@ -203,12 +203,12 @@ if __name__ == '__main__':
     options = {
         'language': 'zh',
         'long_short_sent_handle': True,
-        'max_length': 20,
-        'min_length': 3,
-        'hard_max_length': 20,
+        'max_length': 200,
+        'min_length': 20,
+        'hard_max_length': 200,
         'remove_blank': True
     }
     spliter = Spliter(**options)
-    text = '旁听席．座无虚席,但法庭里并未显现出乡间谋杀案庭审过程中常见的狂欢氛围。'
+    text ='到荷兰境内，干粮完了；但听说当地人人皆是富翁，并且是基督徒，便深信他们待客的情谊决不亚于男爵府上，就是说和他没有为了美丽的居内贡而被逐的时代一样。'
     cut_sent_actual = spliter.cut_to_sentences(text=text)
     print(cut_sent_actual)
\ No newline at end of file
