@@ -11,7 +11,7 @@ def time_measure(func):
         ret = func(*args, **kwargs)
         time_elapsed = time.time() - start
         name = os.path.abspath(func.__name__)
-        print('{0} elapsed {1:.4f} s'.format(name, float(time_elapsed)))
+        #print('{0} elapsed {1:.4f} s'.format(name, float(time_elapsed)))
         # -- save model -- #
         # try:
         #     history = json_load('history.json')
