@@ -11,11 +11,11 @@ def test_spliter():
         'min_length': 15,
     }
     spliter = Spliter(options)
-    input_path = '../test/data/test.txt'
-    output_path = '../test/data/cut_sentences.txt'
+    input_path = '../test/data/249-老实人-zh.txt'
+    output_path = '../test/data/249-老实人-zh_cut.txt.txt'
     with open(input_path,'r',encoding='utf-8') as f_read:
         sentence = f_read.read()
-    logger.debug(sentence)
+    # logger.debug(sentence)
     output_lines = []
     output_lines.extend(spliter.cut_to_sentences(sentence))
     open(output_path, 'w', encoding='utf-8').write('\n'.join(output_lines))
