@@ -225,6 +225,23 @@ def test_cut_to_sentences_en_7():
 
     assert cut_sents_actual == cut_sents_expect
 
+def test_cut_sentences_book():
+    options = {
+        'language': 'zh',
+        'long_short_sent_handle': True,
+        'max_length': 150,
+        'min_length': 15,
+        'hard_max_length': 300,
+        'remove_blank': True
+    }
+    spliter = Spliter(**options)
+    with open('./data/005-假如比尔街可以作证-zh.txt', 'r', encoding='utf-8') as f:
+        sentence = f.read()
+    output_lines = []
+    output_lines.extend(spliter.cut_to_sentences(sentence))
+    output_path = './data/005-假如比尔街可以作证-zh-cut.txt'
+    open(output_path, 'w', encoding='utf-8').write('\n'.join(output_lines))
+
 if __name__ == '__main__':
     test_cut_to_sentences_zh_1()
     test_cut_to_sentences_zh_2()
